Struct llvm_rs::BasicBlock

source ·
pub struct BasicBlock(_);
A container of instructions that execute sequentially.

Implementations

Return the enclosing method, or None if it is not attached to a method.

Get the Insert Block

Return the terminator instruction for this basic block.

Return the first instruction for this basic block.

Return the last instruction for this basic block.

Move this basic block after the other basic block in its function.

Move this basic block before the other basic block in its function.

Unlink from the containing function, but do not delete it.

Delete this basic block.

This is unsafe because there should be no other reference to this, but this can’t be guranteed using Rust semantics.

Methods from Deref<Target = Value>

Returns the name of this value, or None if it lacks a name

Sets the name of this value

Returns the type of this value