Struct llvm_rs::CSemiBox

source ·
pub struct CSemiBox<'a, D>where
    D: 'a + DisposeRef + ?Sized,
{ /* private fields */ }
A wrapper for pointers made by C that are now partially owned in Rust.

This is necessary to allow owned and borrowed representations of C types to be represented by the same type as they are in C with little overhead

Implementations

Wrap the pointer in a CSemiBox

Returns the internal pointer

Returns the internal pointer