Struct llvm_rs::Context

source ·
pub struct Context(_);
Contains all the LLVM entities - mainly modules.

Every single entity attached to it has its lifetime to enforce the rule that things from different contexts cannot interact and to preserve pointer safety.

Implementations

Get a reference to the global context.

This is marked as unsafe because this can result in undefined behaviour in a multithreaded context if they all use the same context.

Create a new context, which is owned by the callee block.