Struct llvm_rs::JitEngine

source ·
pub struct JitEngine(_);
The MCJIT backend, which compiles functions and values into machine code.

Implementations

Run the closure cb with the machine code for the function function.

If the function takes multiple arguments, these should be wrapped in a tuple due to the limitations of Rust’s type system.

This will check that the types match at runtime when in debug mode, but not release mode. You should make sure to use debug mode if you want it to error when the types don’t match.

Run the closure cb with the machine code for the function function.

Returns a pointer to the machine code for the function function.

This is marked as unsafe because the types given as arguments and return could be different from their internal representation.