Struct llvm_rs::ObjectFile

source ·
pub struct ObjectFile { /* private fields */ }
An external object file that has been parsed by LLVM.

Implementations

Parse the object file at the path given, or return an error string if an error occurs.

Iterate through the symbols in this object file.