pub struct Target(_);Implementations
sourceimpl Target
impl Target
sourcepub fn get_description(&self) -> &str
pub fn get_description(&self) -> &str
Returns the description of this target.
sourcepub fn has_asm_backend(&self) -> bool
pub fn has_asm_backend(&self) -> bool
Returns true if this target has an assembly generation backend implemented.
sourcepub fn has_target_machine(&self) -> bool
pub fn has_target_machine(&self) -> bool
Returns true if this target has a target machine.