Struct llvm_rs::TargetData

source ·
pub struct TargetData(_);
Represents an LLVM Target

Implementations

Create a target data from a target layout string.

Returns true if the target is big endian.

Returns the size of a pointer on the target.

Returns the size of the type given in bits.

Returns the size of the type given in bytes.

Returns the alignment of the type given in bytes.

Computes the structure element that contains the byte offset for a target.

Compute the byte offset of an element in the struct type given.

Returns the string representation of this target data.