pub trait GenericValueCast {
    fn to_generic(self, context: &Context) -> CSemiBox<'_, GenericValue>;
    fn from_generic(value: &GenericValue, context: &Context) -> Self;
}
A value that can be cast into a GenericValue and that a GenericValue can be cast into.

Both these methods require contexts because some Type constructors are needed for the conversion and these constructors need a context.

Required Methods

Create a GenericValue from this value.

Convert the GenericValue into a value of this type again.

Implementations on Foreign Types

Implementors