Struct llvm_rs::types::FunctionType
source · pub struct FunctionType(_);Expand description
A function signature type.
Implementations
sourceimpl FunctionType
impl FunctionType
sourcepub fn new<'a>(ret: &'a Type, args: &[&'a Type]) -> &'a FunctionType
pub fn new<'a>(ret: &'a Type, args: &[&'a Type]) -> &'a FunctionType
Make a new function signature with the return type and arguments given.
sourcepub fn num_params(&self) -> usize
pub fn num_params(&self) -> usize
Returns the number of parameters this signature takes.
sourcepub fn get_params(&self) -> Vec<&Type>
pub fn get_params(&self) -> Vec<&Type>
Returns a vector of this signature’s parameters’ types.
sourcepub fn get_return(&self) -> &Type
pub fn get_return(&self) -> &Type
Returns the type that this function returns.
Methods from Deref<Target = Type>
sourcepub fn is_sized(&self) -> bool
pub fn is_sized(&self) -> bool
Returns true if the size of the type is known at compile-time.
This is equivalent to the type implementing Sized in Rust
sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Returns true if this type is a function.
This is equivalent to FunctionType::is.
sourcepub fn is_struct(&self) -> bool
pub fn is_struct(&self) -> bool
Returns true if this type is a struct.
This is equivalent to StructType::is.
sourcepub fn is_pointer(&self) -> bool
pub fn is_pointer(&self) -> bool
Returns true if this type is a pointer.
This is equivalent to PointerType::is.
sourcepub fn is_integer(&self) -> bool
pub fn is_integer(&self) -> bool
Returns true if this type is an integer.
pub fn get_size(&self, target: &TargetData) -> usize