Struct llvm_rs::types::PointerType

source ·
pub struct PointerType(_);
A pointer type.

Implementations

Make a new pointer type with the given element type.

Returns the element of this pointer type.

Methods from Deref<Target = Type>

Returns true if the size of the type is known at compile-time.

This is equivalent to the type implementing Sized in Rust

Returns true if this type is a function.

This is equivalent to FunctionType::is.

Returns true if this type is a struct.

This is equivalent to StructType::is.

Returns true if this type is void.

Returns true if this type is a pointer.

This is equivalent to PointerType::is.

Returns true if this type is an integer.

Returns true if this type is any floating-point number.