Struct llvm_rs::types::StructType

source ·
pub struct StructType(_);
A structure type, such as a tuple or struct.

Implementations

Make a new struct with the given fields and packed representation.

Make a new named struct with the given fields and packed representation.

Make a new named struct without defining its fields yet.

You can use this opaque struct without defining its fields (for creating recursive types, etc.). When you want to define its fields (which may include itself), use set_elements().

Set the elements that make up this struct.

Can only be called once, and only on a StructType created through the new_opaque() function. Returns Err(()) if the struct is not opaque.

Returns the elements that make up this struct.

Methods from Deref<Target = Type>

Returns true if the size of the type is known at compile-time.

This is equivalent to the type implementing Sized in Rust

Returns true if this type is a function.

This is equivalent to FunctionType::is.

Returns true if this type is a struct.

This is equivalent to StructType::is.

Returns true if this type is void.

Returns true if this type is a pointer.

This is equivalent to PointerType::is.

Returns true if this type is an integer.

Returns true if this type is any floating-point number.