pub struct Type(_);Expand description
Defines how a value should be laid out in memory.
Implementations
sourceimpl Type
impl Type
sourcepub fn get<'a, T>(context: &'a Context) -> &'a Typewhere
T: Compile<'a>,
pub fn get<'a, T>(context: &'a Context) -> &'a Typewhere
T: Compile<'a>,
Get the type given as an LLVM type descriptor in the context given.
sourcepub fn is_sized(&self) -> bool
pub fn is_sized(&self) -> bool
Returns true if the size of the type is known at compile-time.
This is equivalent to the type implementing Sized in Rust
sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Returns true if this type is a function.
This is equivalent to FunctionType::is.
sourcepub fn is_struct(&self) -> bool
pub fn is_struct(&self) -> bool
Returns true if this type is a struct.
This is equivalent to StructType::is.
sourcepub fn is_pointer(&self) -> bool
pub fn is_pointer(&self) -> bool
Returns true if this type is a pointer.
This is equivalent to PointerType::is.
sourcepub fn is_integer(&self) -> bool
pub fn is_integer(&self) -> bool
Returns true if this type is an integer.
pub fn get_size(&self, target: &TargetData) -> usize