Struct llvm_rs::value::Alias

source ·
pub struct Alias(_);
An alias to another global value.

Methods from Deref<Target = GlobalValue>

Set the linkage type for this global

Returns the linkage type for this global

Returns true if this global is a declaration (as opposed to a definition).

Methods from Deref<Target = Value>

Returns the name of this value, or None if it lacks a name

Sets the name of this value

Returns the type of this value