Struct llvm_rs::value::Function

source ·
pub struct Function(_);
A function is a kind of value that can be called and contains blocks of code.

To get the value of each argument to a function, you can use the index operator. For example, &func[0] is the value that represents the first argument to the function.

Implementations

Add a basic block with the name given to the function and return it.

Iterate through this function’s basic blocks.

source

pub fn get_entry(&self) -> Option<&BasicBlock>

Returns the entry block of this function or None if there is none.

Returns the function signature representing this function’s signature.

Methods from Deref<Target = GlobalValue>

Set the linkage type for this global

Returns the linkage type for this global

Returns true if this global is a declaration (as opposed to a definition).

Methods from Deref<Target = Value>

Returns the name of this value, or None if it lacks a name

Sets the name of this value

Returns the type of this value