pub struct Value(_);Expand description
A typed value that can be used as an operand in instructions.
Implementations
sourceimpl Value
impl Value
sourcepub fn new_struct<'a>(
context: &'a Context,
vals: &[&'a Value],
packed: bool
) -> &'a Value
pub fn new_struct<'a>(
context: &'a Context,
vals: &[&'a Value],
packed: bool
) -> &'a Value
Create a new constant struct from the values given.
sourcepub fn new_vector<'a>(vals: &[&'a Value]) -> &'a Value
pub fn new_vector<'a>(vals: &[&'a Value]) -> &'a Value
Create a new constant vector from the values given.
sourcepub fn new_string<'a>(
context: &'a Context,
text: &str,
rust_style: bool
) -> &'a Value
pub fn new_string<'a>(
context: &'a Context,
text: &str,
rust_style: bool
) -> &'a Value
Create a new constant C string from the text given.
sourcepub fn new_undef<'a>(ty: &'a Type) -> &'a Value
pub fn new_undef<'a>(ty: &'a Type) -> &'a Value
Create a new constant undefined value of the given type.