Struct llvm_rs::BasicBlock
source · pub struct BasicBlock(_);Expand description
A container of instructions that execute sequentially.
Implementations
sourceimpl BasicBlock
impl BasicBlock
sourcepub fn get_parent(&self) -> Option<&Function>
pub fn get_parent(&self) -> Option<&Function>
Return the enclosing method, or None if it is not attached to a method.
sourcepub fn get_insert_block<'a>(builder: &'a Builder) -> &'a BasicBlock
pub fn get_insert_block<'a>(builder: &'a Builder) -> &'a BasicBlock
Get the Insert Block
sourcepub fn get_terminator(&self) -> Option<&Value>
pub fn get_terminator(&self) -> Option<&Value>
Return the terminator instruction for this basic block.
sourcepub fn move_after(&self, other: &BasicBlock)
pub fn move_after(&self, other: &BasicBlock)
Move this basic block after the other basic block in its function.
sourcepub fn move_before(&self, other: &BasicBlock)
pub fn move_before(&self, other: &BasicBlock)
Move this basic block before the other basic block in its function.
Methods from Deref<Target = Value>