pub struct CSemiBox<'a, D>where
D: 'a + DisposeRef + ?Sized,{ /* private fields */ }
A wrapper for pointers made by C that are now partially owned in Rust.
This is necessary to allow owned and borrowed representations of C types
to be represented by the same type as they are in C with little overhead
Wrap the pointer in a CSemiBox
Returns the internal pointer
Returns the internal pointer
Immutably borrows from an owned value.
Read more
Formats the value using the given formatter.
Read more
The resulting type after dereferencing.
Dereferences the value.
Mutably dereferences the value.
Formats the value using the given formatter.
Read more
Converts to this type from the input type.
Converts to this type from the input type.
This method tests for
self and
other values to be equal, and is used
by
==.
Read more
This method tests for
!=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.