pub struct Context(_);Expand description
Contains all the LLVM entities - mainly modules.
Every single entity attached to it has its lifetime to enforce the rule that things from different contexts cannot interact and to preserve pointer safety.
Implementations