pub struct JitEngine(_);Expand description
The MCJIT backend, which compiles functions and values into machine code.
Implementations
sourceimpl<'a> JitEngine
impl<'a> JitEngine
sourcepub fn with_function<C, A, R>(&self, function: &'a Function, cb: C)where
A: Compile<'a>,
R: Compile<'a>,
C: FnOnce(extern "C" fn(_: A) -> R),
pub fn with_function<C, A, R>(&self, function: &'a Function, cb: C)where
A: Compile<'a>,
R: Compile<'a>,
C: FnOnce(extern "C" fn(_: A) -> R),
Run the closure cb with the machine code for the function function.
If the function takes multiple arguments, these should be wrapped in a tuple due to the limitations of Rust’s type system.
This will check that the types match at runtime when in debug mode, but not release mode. You should make sure to use debug mode if you want it to error when the types don’t match.
sourcepub unsafe fn with_function_unchecked<C, A, R>(
&self,
function: &'a Function,
cb: C
)where
A: Compile<'a>,
R: Compile<'a>,
C: FnOnce(extern "C" fn(_: A) -> R),
pub unsafe fn with_function_unchecked<C, A, R>(
&self,
function: &'a Function,
cb: C
)where
A: Compile<'a>,
R: Compile<'a>,
C: FnOnce(extern "C" fn(_: A) -> R),
Run the closure cb with the machine code for the function function.
sourcepub unsafe fn get_function<A, R>(
&self,
function: &'a Function
) -> extern "C" fn(_: A) -> R
pub unsafe fn get_function<A, R>(
&self,
function: &'a Function
) -> extern "C" fn(_: A) -> R
Returns a pointer to the machine code for the function function.
This is marked as unsafe because the types given as arguments and return could be different from their internal representation.