pub struct Function(_);Expand description
A function is a kind of value that can be called and contains blocks of code.
To get the value of each argument to a function, you can use the index operator.
For example, &func[0] is the value that represents the first argument to the function.
Implementations
sourceimpl Function
impl Function
sourcepub fn append<'a>(&'a self, name: &str) -> &'a BasicBlock
pub fn append<'a>(&'a self, name: &str) -> &'a BasicBlock
Add a basic block with the name given to the function and return it.
sourcepub fn get_entry(&self) -> Option<&BasicBlock>
pub fn get_entry(&self) -> Option<&BasicBlock>
Returns the entry block of this function or None if there is none.
sourcepub fn get_signature(&self) -> &FunctionType
pub fn get_signature(&self) -> &FunctionType
Returns the function signature representing this function’s signature.
Methods from Deref<Target = GlobalValue>
sourcepub fn set_linkage(&self, linkage: Linkage)
pub fn set_linkage(&self, linkage: Linkage)
Set the linkage type for this global
sourcepub fn get_linkage(&self) -> Linkage
pub fn get_linkage(&self) -> Linkage
Returns the linkage type for this global
sourcepub fn is_declaration(&self) -> bool
pub fn is_declaration(&self) -> bool
Returns true if this global is a declaration (as opposed to a definition).
Methods from Deref<Target = Value>